#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mutable-containers
version:              0.3.4.1
visibility:           public
id:                   mutable-containers-0.3.4.1-IchlvAsEH242VgezBTGJCK
key:                  mutable-containers-0.3.4.1-IchlvAsEH242VgezBTGJCK
license:              MIT
maintainer:           michael@fpcomplete.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/mono-traversable#readme
synopsis:
    Abstactions and concrete implementations of mutable containers

description:
    See docs and README at <http://www.stackage.org/package/mutable-containers>

category:             Data
abi:                  b1a6d5a2087005f0362b262d83c60142
exposed:              True
exposed-modules:      Data.Mutable
hidden-modules:
    Data.Mutable.BRef Data.Mutable.Class Data.Mutable.Deque
    Data.Mutable.DLList Data.Mutable.PRef Data.Mutable.SRef
    Data.Mutable.URef Paths_mutable_containers

import-dirs:          /usr/lib/ghc-9.6.6/site-local/mutable-containers-0.3.4.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/mutable-containers-0.3.4.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/mutable-containers-0.3.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mutable-containers
hs-libraries:         HSmutable-containers-0.3.4.1-IchlvAsEH242VgezBTGJCK
depends:
    base-4.18.2.1 containers-0.6.7 ghc-prim-0.10.0
    mono-traversable-1.0.21.0-9ZK15fBAl8H84pzW6JMmSB
    primitive-0.9.1.0-3nzJAQH5hwg1T1vj09oB8B
    vector-0.13.2.0-4h5s991j4Tv2xGOb8nYid2

haddock-interfaces:
    /usr/share/doc/haskell-mutable-containers/html/mutable-containers.haddock

haddock-html:         /usr/share/doc/haskell-mutable-containers/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

